@@ -115,7 +115,7 @@ class VideosResource(Resource):
             raise PyYouTubeException(
                 ErrorMessage(
                     status_code=ErrorCode.MISSING_PARAMS,
-                    message=f"Specify at least one of for_username,channel_id,managedByMe or mine",
+                    message="Specify at least one of chart,video_id or my_rating",
                 )
             )
         response = self._client.request(path="videos", params=params)
